==> haskell-fsnotify-0.3.0.1-324-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-2Nz4SbXD4RhBlmP1S3Ib69
key:                  fsnotify-0.3.0.1-2Nz4SbXD4RhBlmP1S3Ib69
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  d901eace01a1f0b853cca8027fec2907
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.0.2/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.3.0.1-2Nz4SbXD4RhBlmP1S3Ib69
depends:
    async-2.2.4-DJ92HUKWAv9BgiY7swL0mC base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 hinotify-0.4.1-8OXqRbneW2TFAKLD2JWZ9x
    shelly-1.10.0-AhYoamwHVFxGFTkItH6nbQ text-1.2.5.0 time-1.9.3
    unix-2.7.2.2 unix-compat-0.6-HrewfCyDXLJLX32deo1LF7

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify-0.3.0.1-328-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-5EHZX4K49QqFPjaYr1vM1
key:                  fsnotify-0.3.0.1-5EHZX4K49QqFPjaYr1vM1
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  1b24b6077519cf38b3e5a10664ae55e1
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.0.2/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify
hs-libraries:         HSfsnotify-0.3.0.1-5EHZX4K49QqFPjaYr1vM1
depends:
    async-2.2.4-9byXxaHstkgJ8t3QD8BObS base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 hinotify-0.4.1-FiHr3uBTiqzLqUy8oA0YQb
    shelly-1.10.0-808AhtDPvB71vLrjabv2Gb text-1.2.5.0 time-1.9.3
    unix-2.7.2.2 unix-compat-0.6-7DrHnQXtQ8RAOjAfdaVSxI

haddock-interfaces:   /usr/share/doc/haskell-fsnotify/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
